# Copyright 2023 Open Source Robotics Foundation, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# copied from gz-msgs/gz-msgs-extras.cmake

find_package(Python3 REQUIRED COMPONENTS Interpreter)

include(${gz-msgs10_DIR}/gz_msgs_string_utils.cmake)
include(${gz-msgs10_DIR}/gz_msgs_protoc.cmake)
include(${gz-msgs10_DIR}/gz_msgs_factory.cmake)
include(${gz-msgs10_DIR}/gz_msgs_generate.cmake)

set(gz-msgs10_INSTALL_PATH "${gz-msgs10_DIR}/../../../../")

if(CMAKE_VERSION VERSION_LESS "3.20.0") 
  file(TO_CMAKE_PATH gz-msgs10_INSTALL_PATH NORMALIZED_PATH)  # Converts native path to CMake style with forward slashes.
  get_filename_component(ABSOLUTE_PATH "${NORMALIZED_PATH}" ABSOLUTE)  # Extracts the absolute path component.
  set(gz-msgs10_INSTALL_PATH "${ABSOLUTE_PATH}")  # Stores the normalized absolute path back to the original variable.
else()
  cmake_path(NORMAL_PATH gz-msgs10_INSTALL_PATH OUTPUT_VARIABLE gz-msgs10_INSTALL_PATH)
endif()

set(PROTOC_NAME "gz-msgs10_protoc_plugin")
set(PROTO_SCRIPT_NAME "gz-msgs10_generate.py")
set(FACTORY_SCRIPT_NAME "gz-msgs10_generate_factory.py")

set(gz-msgs10_PROTO_PATH ${gz-msgs10_INSTALL_PATH}/share/protos)
# Provide support to override generator executable used during cross-compilation
if(NOT DEFINED gz-msgs10_PROTO_GENERATOR_PLUGIN)
  set(gz-msgs10_PROTO_GENERATOR_PLUGIN ${gz-msgs10_INSTALL_PATH}/bin/${PROTOC_NAME})
endif()
if(NOT DEFINED gz-msgs10_PROTOC_EXECUTABLE)
  set(gz-msgs10_PROTOC_EXECUTABLE protobuf::protoc)
endif()
if(NOT DEFINED gz-msgs10_PYTHON_INTERPRETER)
  set(gz-msgs10_PYTHON_INTERPRETER Python3::Interpreter)
endif()
set(gz-msgs10_PROTO_GENERATOR_SCRIPT ${gz-msgs10_INSTALL_PATH}/bin/${PROTO_SCRIPT_NAME})
set(gz-msgs10_FACTORY_GENERATOR_SCRIPT ${gz-msgs10_INSTALL_PATH}/bin/${FACTORY_SCRIPT_NAME})

##################################################
# A function to generate a target mesage library from a group of protobuf files .
# The generation follows the conventions to make the messages available in gazebo tooling
#
# For an example use, consult gz-msgs/examples/generating_custom_messages
#
# Generally, the structure should be:
#     protos/your/package/foo.proto
#     protos/your/package/bar.proto
#
# In that case, the arguments would be
#     MSGS_PATH ${CMAKE_CURRENT_SOURCE_DIR}/protos
#     PROTO_PACKAGE "your.package"
#     MSGS_PROTOS
#       protos/your/package/foo.proto
#       protos/your/package/bar.proto
#
# One value arguments:
#   MSG_PATHS           - The base path of the proto files
#                         All proto imports are relative to this path
#   PROTO_PACKAGE       - The name of the proto package to generate
#   TARGET              - The name of the generated output target
# Multi value arguments
#   MSGS_PROTOS         - List of input proto files
#   DEPENDENCIES        - List of message libraries this message library depends on
function(gz_msgs_generate_messages)
  set(options "")
  set(oneValueArgs MSGS_PATH TARGET PROTO_PACKAGE OUTPUT_DIRECTORY)
  set(multiValueArgs MSGS_PROTOS DEPENDENCIES)

  cmake_parse_arguments(generate_messages "${options}" "${oneValueArgs}" "${multiValueArgs}" ${ARGN})
  gz_msgs_generate_messages_lib(
    PYTHON_INTERPRETER
      ${gz-msgs10_PYTHON_INTERPRETER}
    PROTOC_EXEC
      ${gz-msgs10_PROTOC_EXECUTABLE}
    MSGS_GEN_SCRIPT
      ${gz-msgs10_PROTO_GENERATOR_SCRIPT}
    FACTORY_GEN_SCRIPT
      ${gz-msgs10_FACTORY_GENERATOR_SCRIPT}
    GZ_PROTOC_PLUGIN
      ${gz-msgs10_PROTO_GENERATOR_PLUGIN}
    INPUT_PROTOS
      ${generate_messages_MSGS_PROTOS}
    PROTO_PACKAGE
      ${generate_messages_PROTO_PACKAGE}
    PROTO_PATH
      ${generate_messages_MSGS_PATH}
    MSGS_LIB
      gz-msgs10::gz-msgs10
    DEPENDENCIES
      ${generate_messages_DEPENDENCIES}
    TARGET
      ${generate_messages_TARGET}
  )
endfunction()
